Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(670)

Unified Diff: tests/cli_tests/interactive_debugger_tests.dart

Issue 1659163007: Rename fletch -> dartino (Closed) Base URL: https://github.com/dartino/sdk.git@master
Patch Set: Created 4 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: tests/cli_tests/interactive_debugger_tests.dart
diff --git a/tests/cli_tests/interactive_debugger_tests.dart b/tests/cli_tests/interactive_debugger_tests.dart
index 42367871aac53075bcc5bf73271ac69ec6d144ba..e351c02f5ed64460bab17ef84b95a4c9068f6f90 100644
--- a/tests/cli_tests/interactive_debugger_tests.dart
+++ b/tests/cli_tests/interactive_debugger_tests.dart
@@ -24,7 +24,7 @@ import 'cli_tests.dart' show
import 'prompt_splitter.dart' show
PromptSplitter;
-import 'package:fletchc/src/hub/exit_codes.dart' show
+import 'package:dartino_compiler/src/hub/exit_codes.dart' show
DART_VM_EXITCODE_UNCAUGHT_EXCEPTION;
final List<CliTest> tests = <CliTest>[
@@ -49,7 +49,7 @@ abstract class InteractiveDebuggerTest extends CliTest {
Future<Null> internalRun();
Future<Null> run() async {
- process = await fletch(["debug", testFilePath],
+ process = await dartino(["debug", testFilePath],
workingDirectory: workingDirectory);
out = new StreamIterator(
process.stdout.transform(UTF8.decoder).transform(new PromptSplitter()));
@@ -152,7 +152,7 @@ class DebuggerListProcessesTest extends InteractiveDebuggerTest {
class DebuggerRelativeFileReferenceTest extends InteractiveDebuggerTest {
// Working directory that is not the fletch-root directory.
final String workingDirectory = "$thisDirectory/../";
// Relative reference to the test file.
@@ -152,7 +152,7 @@ class DebuggerListProcessesTest extends InteractiveDebuggerTest {
class DebuggerRelativeFileReferenceTest extends InteractiveDebuggerTest {
- // Working directory that is not the fletch-root directory.
+ // Working directory that is not the dartino-root directory.
final String workingDirectory = "$thisDirectory/../";
// Relative reference to the test file.

Powered by Google App Engine
This is Rietveld 408576698